Description Usage Format Examples
This dataset provides a small sample of variables related to happiness from the general social survey (GSS).
It is a reexport of the productplots::happy dataset, converted into a tibble.
1 |
An object of class tbl_df (inherits from tbl, data.frame) with 51020 rows and 10 columns.
1 2 3 4 5 6 7 8 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.